slepc-3.18.0 2022-10-01
Report Typos and Errors

# EPSEVSLGetRange

Gets the interval containing all eigenvalues.

### Synopsis

    #include "slepceps.h"
    PetscErrorCode EPSEVSLGetRange(EPS eps,PetscReal *lmin,PetscReal *lmax)

Not Collective

### Input Parameter

| eps | - the eigensolver context

### Output Parameters

| lmin | - left end of the interval
| lmax | - right end of the interval

### See Also

EPSEVSLSetRange()

### Level

intermediate

### Location

src/eps/impls/external/evsl/evsl.c
Index of all EPS routines
Table of Contents for all manual pages
Index of all manual pages